# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/discussion/post_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/discussion/post_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.discussion import post_pb2 as eolymp_dot_discussion_dot_post__pb2
from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$eolymp/discussion/post_service.proto\x12\x11\x65olymp.discussion\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1c\x65olymp/discussion/post.proto\x1a\x18\x65olymp/ecm/content.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\"\x88\x01\n\x10PostChangedEvent\x12\'\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x17.eolymp.discussion.Post\x12&\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x17.eolymp.discussion.Post\x12#\n\x06reason\x18\x0b \x01(\x0b\x32\x13.eolymp.ecm.Content\"s\n\x12PostPublishedEvent\x12\x11\n\tpublished\x18\x01 \x01(\x08\x12%\n\x04post\x18\x02 \x01(\x0b\x32\x17.eolymp.discussion.Post\x12#\n\x06reason\x18\x03 \x01(\x0b\x32\x13.eolymp.ecm.Content\"\xbc\x01\n\x1bPostTranslationChangedEvent\x12\x0f\n\x07post_id\x18\n \x01(\t\x12\x33\n\x06\x62\x65\x66ore\x18\x02 \x01(\x0b\x32#.eolymp.discussion.Post.Translation\x12\x32\n\x05\x61\x66ter\x18\x03 \x01(\x0b\x32#.eolymp.discussion.Post.Translation\x12#\n\x06reason\x18\x0b \x01(\x0b\x32\x13.eolymp.ecm.Content\"c\n\x11\x44\x65scribePostInput\x12\x0f\n\x07post_id\x18\x01 \x01(\t\x12\x0e\n\x06locale\x18< \x01(\t\x12-\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1d.eolymp.discussion.Post.Extra\";\n\x12\x44\x65scribePostOutput\x12%\n\x04post\x18\x01 \x01(\x0b\x32\x17.eolymp.discussion.Post\"\xbc\x08\n\x0eListPostsInput\x12\r\n\x05\x61\x66ter\x18\n \x01(\t\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x0e\n\x06offset\x18\x0c \x01(\x05\x12\x34\n\x04sort\x18\x32 \x01(\x0e\x32&.eolymp.discussion.ListPostsInput.Sort\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x12\x39\n\x07\x66ilters\x18( \x01(\x0b\x32(.eolymp.discussion.ListPostsInput.Filter\x12\x0e\n\x06locale\x18< \x01(\t\x12-\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1d.eolymp.discussion.Post.Extra\x1a\xb3\x05\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tsource_id\x18\r \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12/\n\x07user_id\x18\x03 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tmember_id\x18\x04 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12/\n\x07type_id\x18\x08 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x39\n\ncreated_at\x18\x05 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12;\n\x0cpublished_at\x18\x06 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12/\n\x05\x64raft\x18\x0e \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x30\n\x06public\x18\x0c \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x32\n\x08\x66\x65\x61tured\x18\x0f \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x34\n\nmoderation\x18\x0b \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x06locale\x18\t \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12/\n\x05label\x18\n \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"k\n\x04Sort\x12\x10\n\x0cUNKNOWN_SORT\x10\x00\x12\x10\n\x0cPUBLISHED_AT\x10\x01\x12\x0e\n\nCREATED_AT\x10\x02\x12\x0e\n\nVOTE_COUNT\x10\x03\x12\x0f\n\x0bREPLY_COUNT\x10\x04\x12\x0e\n\nPOPULARITY\x10\x05\"b\n\x0fListPostsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.eolymp.discussion.Post\x12\x18\n\x10next_page_cursor\x18\x03 \x01(\t\"8\n\x0f\x43reatePostInput\x12%\n\x04post\x18\x01 \x01(\x0b\x32\x17.eolymp.discussion.Post\"#\n\x10\x43reatePostOutput\x12\x0f\n\x07post_id\x18\x01 \x01(\t\"\xfb\x01\n\x0fUpdatePostInput\x12\x37\n\x05patch\x18\x01 \x03(\x0e\x32(.eolymp.discussion.UpdatePostInput.Patch\x12\x0f\n\x07post_id\x18\x02 \x01(\t\x12%\n\x04post\x18\x03 \x01(\x0b\x32\x17.eolymp.discussion.Post\"w\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x0b\n\x07\x43ONTENT\x10\x01\x12\n\n\x06LABELS\x10\x02\x12\x0b\n\x07TYPE_ID\x10\x03\x12\n\n\x06LOCALE\x10\x04\x12\t\n\x05\x44RAFT\x10\x05\x12\x0c\n\x08\x46\x45\x41TURED\x10\x07\x12\n\n\x06PINNED\x10\x08\x12\x0e\n\nMODERATION\x10\x06\"\x12\n\x10UpdatePostOutput\"#\n\x10PublishPostInput\x12\x0f\n\x07post_id\x18\x01 \x01(\t\"\x13\n\x11PublishPostOutput\"J\n\x12UnpublishPostInput\x12\x0f\n\x07post_id\x18\x01 \x01(\t\x12#\n\x06reason\x18\x0b \x01(\x0b\x32\x13.eolymp.ecm.Content\"\x15\n\x13UnpublishPostOutput\"\xd3\x01\n\x11ModeratePostInput\x12\x0f\n\x07post_id\x18\x01 \x01(\t\x12=\n\x07outcome\x18\x02 \x01(\x0e\x32,.eolymp.discussion.ModeratePostInput.Outcome\x12#\n\x06reason\x18\x0b \x01(\x0b\x32\x13.eolymp.ecm.Content\"I\n\x07Outcome\x12\x13\n\x0fUNKNOWN_OUTCOME\x10\x00\x12\x0c\n\x08\x41PPROVED\x10\x01\x12\x0c\n\x08REJECTED\x10\x02\x12\r\n\tIN_REVIEW\x10\x03\"\x14\n\x12ModeratePostOutput\"\"\n\x0f\x44\x65letePostInput\x12\x0f\n\x07post_id\x18\x01 \x01(\t\"7\n\x10\x44\x65letePostOutput\x12#\n\x06reason\x18\x0b \x01(\x0b\x32\x13.eolymp.ecm.Content\".\n\rVotePostInput\x12\x0f\n\x07post_id\x18\x01 \x01(\t\x12\x0c\n\x04vote\x18\x02 \x01(\x05\"$\n\x0eVotePostOutput\x12\x12\n\nvote_count\x18\x01 \x01(\x05\"x\n\x12TranslatePostInput\x12\x0f\n\x07post_id\x18\x01 \x01(\t\x12\x0e\n\x06source\x18\x02 \x01(\t\x12\x0e\n\x06target\x18\x03 \x03(\t\x12\x18\n\x10target_automatic\x18\x04 \x01(\x08\x12\x17\n\x0foverride_manual\x18\x05 \x01(\x08\"%\n\x13TranslatePostOutput\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"v\n\x1c\x44\x65scribePostTranslationInput\x12\x0f\n\x07post_id\x18\x01 \x01(\t\x12\x16\n\x0etranslation_id\x18\x02 \x01(\t\x12-\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1d.eolymp.discussion.Post.Extra\"Y\n\x1d\x44\x65scribePostTranslationOutput\x12\x38\n\x0btranslation\x18\x01 \x01(\x0b\x32#.eolymp.discussion.Post.Translation\"\xb6\x02\n\x19ListPostTranslationsInput\x12\x0f\n\x07post_id\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x44\n\x07\x66ilters\x18( \x01(\x0b\x32\x33.eolymp.discussion.ListPostTranslationsInput.Filter\x12-\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1d.eolymp.discussion.Post.Extra\x1au\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x06locale\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"_\n\x1aListPostTranslationsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\x32\n\x05items\x18\x02 \x03(\x0b\x32#.eolymp.discussion.Post.Translation\"g\n\x1a\x43reatePostTranslationInput\x12\x0f\n\x07post_id\x18\x01 \x01(\t\x12\x38\n\x0btranslation\x18\x02 \x01(\x0b\x32#.eolymp.discussion.Post.Translation\"5\n\x1b\x43reatePostTranslationOutput\x12\x16\n\x0etranslation_id\x18\x01 \x01(\t\"\xfa\x01\n\x1aUpdatePostTranslationInput\x12\x42\n\x05patch\x18\x01 \x03(\x0e\x32\x33.eolymp.discussion.UpdatePostTranslationInput.Patch\x12\x0f\n\x07post_id\x18\x02 \x01(\t\x12\x16\n\x0etranslation_id\x18\x03 \x01(\t\x12\x38\n\x0btranslation\x18\x04 \x01(\x0b\x32#.eolymp.discussion.Post.Translation\"5\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x0b\n\x07\x43ONTENT\x10\x01\x12\n\n\x06LABELS\x10\x02\x12\n\n\x06LOCALE\x10\x04\"\x1d\n\x1bUpdatePostTranslationOutput\"E\n\x1a\x44\x65letePostTranslationInput\x12\x0f\n\x07post_id\x18\x01 \x01(\t\x12\x16\n\x0etranslation_id\x18\x02 \x01(\t\"\x1d\n\x1b\x44\x65letePostTranslationOutput2\xaf\x15\n\x0bPostService\x12\xa1\x01\n\x0c\x44\x65scribePost\x12$.eolymp.discussion.DescribePostInput\x1a%.eolymp.discussion.DescribePostOutput\"D\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xe3\n\x18\x8a\xe3\n\x14\x64iscussion:post:read\x82\xd3\xe4\x93\x02\x12\x12\x10/posts/{post_id}\x12\x8d\x01\n\tListPosts\x12!.eolymp.discussion.ListPostsInput\x1a\".eolymp.discussion.ListPostsOutput\"9\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x18\x8a\xe3\n\x14\x64iscussion:post:read\x82\xd3\xe4\x93\x02\x08\x12\x06/posts\x12\x91\x01\n\nCreatePost\x12\".eolymp.discussion.CreatePostInput\x1a#.eolymp.discussion.CreatePostOutput\":\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x19\x8a\xe3\n\x15\x64iscussion:post:write\x82\xd3\xe4\x93\x02\x08\"\x06/posts\x12\x9b\x01\n\nUpdatePost\x12\".eolymp.discussion.UpdatePostInput\x1a#.eolymp.discussion.UpdatePostOutput\"D\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x19\x8a\xe3\n\x15\x64iscussion:post:write\x82\xd3\xe4\x93\x02\x12\x1a\x10/posts/{post_id}\x12\xa6\x01\n\x0bPublishPost\x12#.eolymp.discussion.PublishPostInput\x1a$.eolymp.discussion.PublishPostOutput\"L\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x19\x8a\xe3\n\x15\x64iscussion:post:write\x82\xd3\xe4\x93\x02\x1a\"\x18/posts/{post_id}/publish\x12\xac\x01\n\rUnpublishPost\x12%.eolymp.discussion.UnpublishPostInput\x1a&.eolymp.discussion.UnpublishPostOutput\"L\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x19\x8a\xe3\n\x15\x64iscussion:post:write\x82\xd3\xe4\x93\x02\x1a*\x18/posts/{post_id}/publish\x12\xaa\x01\n\x0cModeratePost\x12$.eolymp.discussion.ModeratePostInput\x1a%.eolymp.discussion.ModeratePostOutput\"M\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x19\x8a\xe3\n\x15\x64iscussion:post:write\x82\xd3\xe4\x93\x02\x1b\"\x19/posts/{post_id}/moderate\x12\x9b\x01\n\nDeletePost\x12\".eolymp.discussion.DeletePostInput\x1a#.eolymp.discussion.DeletePostOutput\"D\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x19\x8a\xe3\n\x15\x64iscussion:post:write\x82\xd3\xe4\x93\x02\x12*\x10/posts/{post_id}\x12\x9d\x01\n\x08VotePost\x12 .eolymp.discussion.VotePostInput\x1a!.eolymp.discussion.VotePostOutput\"L\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1c\x8a\xe3\n\x18\x64iscussion:message:write\x82\xd3\xe4\x93\x02\x17\"\x15/posts/{post_id}/vote\x12\xb1\x01\n\rTranslatePost\x12%.eolymp.discussion.TranslatePostInput\x1a&.eolymp.discussion.TranslatePostOutput\"Q\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x1c\x8a\xe3\n\x18\x64iscussion:message:write\x82\xd3\xe4\x93\x02\x1c\"\x1a/posts/{post_id}/translate\x12\xe4\x01\n\x17\x44\x65scribePostTranslation\x12/.eolymp.discussion.DescribePostTranslationInput\x1a\x30.eolymp.discussion.DescribePostTranslationOutput\"f\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xe3\n\x1c\x8a\xe3\n\x18typewriter:fragment:read\x82\xd3\xe4\x93\x02\x30\x12./posts/{post_id}/translations/{translation_id}\x12\xc9\x01\n\x14ListPostTranslations\x12,.eolymp.discussion.ListPostTranslationsInput\x1a-.eolymp.discussion.ListPostTranslationsOutput\"T\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x1c\x8a\xe3\n\x18typewriter:fragment:read\x82\xd3\xe4\x93\x02\x1f\x12\x1d/posts/{post_id}/translations\x12\xcd\x01\n\x15\x43reatePostTranslation\x12-.eolymp.discussion.CreatePostTranslationInput\x1a..eolymp.discussion.CreatePostTranslationOutput\"U\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1d\x8a\xe3\n\x19typewriter:fragment:write\x82\xd3\xe4\x93\x02\x1f\"\x1d/posts/{post_id}/translations\x12\xde\x01\n\x15UpdatePostTranslation\x12-.eolymp.discussion.UpdatePostTranslationInput\x1a..eolymp.discussion.UpdatePostTranslationOutput\"f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1d\x8a\xe3\n\x19typewriter:fragment:write\x82\xd3\xe4\x93\x02\x30\x1a./posts/{post_id}/translations/{translation_id}\x12\xde\x01\n\x15\x44\x65letePostTranslation\x12-.eolymp.discussion.DeletePostTranslationInput\x1a..eolymp.discussion.DeletePostTranslationOutput\"f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1d\x8a\xe3\n\x19typewriter:fragment:write\x82\xd3\xe4\x93\x02\x30*./posts/{post_id}/translations/{translation_id}B7Z5github.com/eolymp/go-sdk/eolymp/discussion;discussionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.discussion.post_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/discussion;discussion'
  _globals['_POSTSERVICE'].methods_by_name['DescribePost']._loaded_options = None
  _globals['_POSTSERVICE'].methods_by_name['DescribePost']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\343\n\030\212\343\n\024discussion:post:read\202\323\344\223\002\022\022\020/posts/{post_id}'
  _globals['_POSTSERVICE'].methods_by_name['ListPosts']._loaded_options = None
  _globals['_POSTSERVICE'].methods_by_name['ListPosts']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\030\212\343\n\024discussion:post:read\202\323\344\223\002\010\022\006/posts'
  _globals['_POSTSERVICE'].methods_by_name['CreatePost']._loaded_options = None
  _globals['_POSTSERVICE'].methods_by_name['CreatePost']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\031\212\343\n\025discussion:post:write\202\323\344\223\002\010\"\006/posts'
  _globals['_POSTSERVICE'].methods_by_name['UpdatePost']._loaded_options = None
  _globals['_POSTSERVICE'].methods_by_name['UpdatePost']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\031\212\343\n\025discussion:post:write\202\323\344\223\002\022\032\020/posts/{post_id}'
  _globals['_POSTSERVICE'].methods_by_name['PublishPost']._loaded_options = None
  _globals['_POSTSERVICE'].methods_by_name['PublishPost']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\031\212\343\n\025discussion:post:write\202\323\344\223\002\032\"\030/posts/{post_id}/publish'
  _globals['_POSTSERVICE'].methods_by_name['UnpublishPost']._loaded_options = None
  _globals['_POSTSERVICE'].methods_by_name['UnpublishPost']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\031\212\343\n\025discussion:post:write\202\323\344\223\002\032*\030/posts/{post_id}/publish'
  _globals['_POSTSERVICE'].methods_by_name['ModeratePost']._loaded_options = None
  _globals['_POSTSERVICE'].methods_by_name['ModeratePost']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\031\212\343\n\025discussion:post:write\202\323\344\223\002\033\"\031/posts/{post_id}/moderate'
  _globals['_POSTSERVICE'].methods_by_name['DeletePost']._loaded_options = None
  _globals['_POSTSERVICE'].methods_by_name['DeletePost']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\031\212\343\n\025discussion:post:write\202\323\344\223\002\022*\020/posts/{post_id}'
  _globals['_POSTSERVICE'].methods_by_name['VotePost']._loaded_options = None
  _globals['_POSTSERVICE'].methods_by_name['VotePost']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\034\212\343\n\030discussion:message:write\202\323\344\223\002\027\"\025/posts/{post_id}/vote'
  _globals['_POSTSERVICE'].methods_by_name['TranslatePost']._loaded_options = None
  _globals['_POSTSERVICE'].methods_by_name['TranslatePost']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\034\212\343\n\030discussion:message:write\202\323\344\223\002\034\"\032/posts/{post_id}/translate'
  _globals['_POSTSERVICE'].methods_by_name['DescribePostTranslation']._loaded_options = None
  _globals['_POSTSERVICE'].methods_by_name['DescribePostTranslation']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\343\n\034\212\343\n\030typewriter:fragment:read\202\323\344\223\0020\022./posts/{post_id}/translations/{translation_id}'
  _globals['_POSTSERVICE'].methods_by_name['ListPostTranslations']._loaded_options = None
  _globals['_POSTSERVICE'].methods_by_name['ListPostTranslations']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\034\212\343\n\030typewriter:fragment:read\202\323\344\223\002\037\022\035/posts/{post_id}/translations'
  _globals['_POSTSERVICE'].methods_by_name['CreatePostTranslation']._loaded_options = None
  _globals['_POSTSERVICE'].methods_by_name['CreatePostTranslation']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\035\212\343\n\031typewriter:fragment:write\202\323\344\223\002\037\"\035/posts/{post_id}/translations'
  _globals['_POSTSERVICE'].methods_by_name['UpdatePostTranslation']._loaded_options = None
  _globals['_POSTSERVICE'].methods_by_name['UpdatePostTranslation']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\035\212\343\n\031typewriter:fragment:write\202\323\344\223\0020\032./posts/{post_id}/translations/{translation_id}'
  _globals['_POSTSERVICE'].methods_by_name['DeletePostTranslation']._loaded_options = None
  _globals['_POSTSERVICE'].methods_by_name['DeletePostTranslation']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\035\212\343\n\031typewriter:fragment:write\202\323\344\223\0020*./posts/{post_id}/translations/{translation_id}'
  _globals['_POSTCHANGEDEVENT']._serialized_start=284
  _globals['_POSTCHANGEDEVENT']._serialized_end=420
  _globals['_POSTPUBLISHEDEVENT']._serialized_start=422
  _globals['_POSTPUBLISHEDEVENT']._serialized_end=537
  _globals['_POSTTRANSLATIONCHANGEDEVENT']._serialized_start=540
  _globals['_POSTTRANSLATIONCHANGEDEVENT']._serialized_end=728
  _globals['_DESCRIBEPOSTINPUT']._serialized_start=730
  _globals['_DESCRIBEPOSTINPUT']._serialized_end=829
  _globals['_DESCRIBEPOSTOUTPUT']._serialized_start=831
  _globals['_DESCRIBEPOSTOUTPUT']._serialized_end=890
  _globals['_LISTPOSTSINPUT']._serialized_start=893
  _globals['_LISTPOSTSINPUT']._serialized_end=1977
  _globals['_LISTPOSTSINPUT_FILTER']._serialized_start=1177
  _globals['_LISTPOSTSINPUT_FILTER']._serialized_end=1868
  _globals['_LISTPOSTSINPUT_SORT']._serialized_start=1870
  _globals['_LISTPOSTSINPUT_SORT']._serialized_end=1977
  _globals['_LISTPOSTSOUTPUT']._serialized_start=1979
  _globals['_LISTPOSTSOUTPUT']._serialized_end=2077
  _globals['_CREATEPOSTINPUT']._serialized_start=2079
  _globals['_CREATEPOSTINPUT']._serialized_end=2135
  _globals['_CREATEPOSTOUTPUT']._serialized_start=2137
  _globals['_CREATEPOSTOUTPUT']._serialized_end=2172
  _globals['_UPDATEPOSTINPUT']._serialized_start=2175
  _globals['_UPDATEPOSTINPUT']._serialized_end=2426
  _globals['_UPDATEPOSTINPUT_PATCH']._serialized_start=2307
  _globals['_UPDATEPOSTINPUT_PATCH']._serialized_end=2426
  _globals['_UPDATEPOSTOUTPUT']._serialized_start=2428
  _globals['_UPDATEPOSTOUTPUT']._serialized_end=2446
  _globals['_PUBLISHPOSTINPUT']._serialized_start=2448
  _globals['_PUBLISHPOSTINPUT']._serialized_end=2483
  _globals['_PUBLISHPOSTOUTPUT']._serialized_start=2485
  _globals['_PUBLISHPOSTOUTPUT']._serialized_end=2504
  _globals['_UNPUBLISHPOSTINPUT']._serialized_start=2506
  _globals['_UNPUBLISHPOSTINPUT']._serialized_end=2580
  _globals['_UNPUBLISHPOSTOUTPUT']._serialized_start=2582
  _globals['_UNPUBLISHPOSTOUTPUT']._serialized_end=2603
  _globals['_MODERATEPOSTINPUT']._serialized_start=2606
  _globals['_MODERATEPOSTINPUT']._serialized_end=2817
  _globals['_MODERATEPOSTINPUT_OUTCOME']._serialized_start=2744
  _globals['_MODERATEPOSTINPUT_OUTCOME']._serialized_end=2817
  _globals['_MODERATEPOSTOUTPUT']._serialized_start=2819
  _globals['_MODERATEPOSTOUTPUT']._serialized_end=2839
  _globals['_DELETEPOSTINPUT']._serialized_start=2841
  _globals['_DELETEPOSTINPUT']._serialized_end=2875
  _globals['_DELETEPOSTOUTPUT']._serialized_start=2877
  _globals['_DELETEPOSTOUTPUT']._serialized_end=2932
  _globals['_VOTEPOSTINPUT']._serialized_start=2934
  _globals['_VOTEPOSTINPUT']._serialized_end=2980
  _globals['_VOTEPOSTOUTPUT']._serialized_start=2982
  _globals['_VOTEPOSTOUTPUT']._serialized_end=3018
  _globals['_TRANSLATEPOSTINPUT']._serialized_start=3020
  _globals['_TRANSLATEPOSTINPUT']._serialized_end=3140
  _globals['_TRANSLATEPOSTOUTPUT']._serialized_start=3142
  _globals['_TRANSLATEPOSTOUTPUT']._serialized_end=3179
  _globals['_DESCRIBEPOSTTRANSLATIONINPUT']._serialized_start=3181
  _globals['_DESCRIBEPOSTTRANSLATIONINPUT']._serialized_end=3299
  _globals['_DESCRIBEPOSTTRANSLATIONOUTPUT']._serialized_start=3301
  _globals['_DESCRIBEPOSTTRANSLATIONOUTPUT']._serialized_end=3390
  _globals['_LISTPOSTTRANSLATIONSINPUT']._serialized_start=3393
  _globals['_LISTPOSTTRANSLATIONSINPUT']._serialized_end=3703
  _globals['_LISTPOSTTRANSLATIONSINPUT_FILTER']._serialized_start=3586
  _globals['_LISTPOSTTRANSLATIONSINPUT_FILTER']._serialized_end=3703
  _globals['_LISTPOSTTRANSLATIONSOUTPUT']._serialized_start=3705
  _globals['_LISTPOSTTRANSLATIONSOUTPUT']._serialized_end=3800
  _globals['_CREATEPOSTTRANSLATIONINPUT']._serialized_start=3802
  _globals['_CREATEPOSTTRANSLATIONINPUT']._serialized_end=3905
  _globals['_CREATEPOSTTRANSLATIONOUTPUT']._serialized_start=3907
  _globals['_CREATEPOSTTRANSLATIONOUTPUT']._serialized_end=3960
  _globals['_UPDATEPOSTTRANSLATIONINPUT']._serialized_start=3963
  _globals['_UPDATEPOSTTRANSLATIONINPUT']._serialized_end=4213
  _globals['_UPDATEPOSTTRANSLATIONINPUT_PATCH']._serialized_start=4160
  _globals['_UPDATEPOSTTRANSLATIONINPUT_PATCH']._serialized_end=4213
  _globals['_UPDATEPOSTTRANSLATIONOUTPUT']._serialized_start=4215
  _globals['_UPDATEPOSTTRANSLATIONOUTPUT']._serialized_end=4244
  _globals['_DELETEPOSTTRANSLATIONINPUT']._serialized_start=4246
  _globals['_DELETEPOSTTRANSLATIONINPUT']._serialized_end=4315
  _globals['_DELETEPOSTTRANSLATIONOUTPUT']._serialized_start=4317
  _globals['_DELETEPOSTTRANSLATIONOUTPUT']._serialized_end=4346
  _globals['_POSTSERVICE']._serialized_start=4349
  _globals['_POSTSERVICE']._serialized_end=7084
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/universe/space.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/universe/space.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.universe import quota_pb2 as eolymp_dot_universe_dot_quota__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x65olymp/universe/space.proto\x12\x0f\x65olymp.universe\x1a\x1b\x65olymp/universe/quota.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa7\x07\n\x05Space\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x10\n\x08home_url\x18\x32 \x01(\t\x12\x12\n\nissuer_url\x18\x33 \x01(\t\x12\x13\n\x0bgraphql_url\x18\x34 \x01(\t\x12\x0c\n\x04name\x18\n \x01(\t\x12\r\n\x05image\x18\x0b \x01(\t\x12\x35\n\nvisibility\x18\x0e \x01(\x0e\x32!.eolymp.universe.Space.Visibility\x12\x30\n\x08\x66\x65\x61tures\x18\x11 \x03(\x0e\x32\x1e.eolymp.universe.Space.Feature\x12-\n\x06status\x18\x10 \x01(\x0e\x32\x1d.eolymp.universe.Space.Status\x12:\n\x0csubscription\x18\xa0\x06 \x01(\x0b\x32#.eolymp.universe.Space.Subscription\x12\x13\n\x0b\x61\x66\x66iliation\x18\x0f \x01(\t\x1a\xb2\x02\n\x0cSubscription\x12\x0c\n\x04plan\x18\x01 \x01(\t\x12\r\n\x05seats\x18\x02 \x01(\r\x12%\n\x05quota\x18\n \x01(\x0b\x32\x16.eolymp.universe.Quota\x12\x38\n\x14\x62illing_period_start\x18Z \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x36\n\x12\x62illing_period_end\x18[ \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x36\n\x12quota_period_start\x18\\ \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10quota_period_end\x18] \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"B\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\t\n\x05TRIAL\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\r\n\tSUSPENDED\x10\x03\"=\n\nVisibility\x12\x16\n\x12UNKNOWN_VISIBILITY\x10\x00\x12\n\n\x06PUBLIC\x10\x01\x12\x0b\n\x07PRIVATE\x10\x02\",\n\x05\x45xtra\x12\x11\n\rUNKNOWN_EXTRA\x10\x00\x12\x10\n\x0cSUBSCRIPTION\x10\x01\"Q\n\x07\x46\x65\x61ture\x12\x13\n\x0fUNKNOWN_FEATURE\x10\x00\x12\x0c\n\x08PRINTERS\x10\x01\x12\x0f\n\x0bNEWSLETTERS\x10\x02\x12\x12\n\x0eMEMBER_CREDITS\x10\x03\x42\x33Z1github.com/eolymp/go-sdk/eolymp/universe;universeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.universe.space_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/universe;universe'
  _globals['_SPACE']._serialized_start=111
  _globals['_SPACE']._serialized_end=1046
  _globals['_SPACE_SUBSCRIPTION']._serialized_start=480
  _globals['_SPACE_SUBSCRIPTION']._serialized_end=786
  _globals['_SPACE_STATUS']._serialized_start=788
  _globals['_SPACE_STATUS']._serialized_end=854
  _globals['_SPACE_VISIBILITY']._serialized_start=856
  _globals['_SPACE_VISIBILITY']._serialized_end=917
  _globals['_SPACE_EXTRA']._serialized_start=919
  _globals['_SPACE_EXTRA']._serialized_end=963
  _globals['_SPACE_FEATURE']._serialized_start=965
  _globals['_SPACE_FEATURE']._serialized_end=1046
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/executor/usage.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/executor/usage.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x65olymp/executor/usage.proto\x12\x0f\x65olymp.executor\"\x95\x02\n\rResourceUsage\x12\x15\n\ruser_cpu_time\x18\x01 \x01(\r\x12\x17\n\x0fsystem_cpu_time\x18\x02 \x01(\r\x12\x1d\n\x15max_resident_set_size\x18\x03 \x01(\r\x12\x15\n\rpage_reclaims\x18\x04 \x01(\r\x12\x13\n\x0bpage_faults\x18\x05 \x01(\r\x12\x1e\n\x16\x62lock_input_operations\x18\x06 \x01(\r\x12\x1f\n\x17\x62lock_output_operations\x18\x07 \x01(\r\x12\"\n\x1avoluntary_context_switches\x18\x08 \x01(\r\x12$\n\x1cinvoluntary_context_switches\x18\t \x01(\rB3Z1github.com/eolymp/go-sdk/eolymp/executor;executorb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.executor.usage_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/executor;executor'
  _globals['_RESOURCEUSAGE']._serialized_start=49
  _globals['_RESOURCEUSAGE']._serialized_end=326
# @@protoc_insertion_point(module_scope)



import datetime

from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ExpressionID(_message.Message):
    __slots__ = ("value",)
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        NONE: _ClassVar[ExpressionID.Type]
        EQUAL: _ClassVar[ExpressionID.Type]
        NOT_EQUAL: _ClassVar[ExpressionID.Type]
    NONE: ExpressionID.Type
    EQUAL: ExpressionID.Type
    NOT_EQUAL: ExpressionID.Type
    IS_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    value: str
    def __init__(self, value: _Optional[str] = ..., **kwargs) -> None: ...

class ExpressionInt(_message.Message):
    __slots__ = ("value",)
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        NONE: _ClassVar[ExpressionInt.Type]
        EQUAL: _ClassVar[ExpressionInt.Type]
        NOT_EQUAL: _ClassVar[ExpressionInt.Type]
        GREATER_THAN: _ClassVar[ExpressionInt.Type]
        GREATER_THAN_EQUAL: _ClassVar[ExpressionInt.Type]
        LESS_THAN: _ClassVar[ExpressionInt.Type]
        LESS_THAN_EQUAL: _ClassVar[ExpressionInt.Type]
    NONE: ExpressionInt.Type
    EQUAL: ExpressionInt.Type
    NOT_EQUAL: ExpressionInt.Type
    GREATER_THAN: ExpressionInt.Type
    GREATER_THAN_EQUAL: ExpressionInt.Type
    LESS_THAN: ExpressionInt.Type
    LESS_THAN_EQUAL: ExpressionInt.Type
    IS_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    value: int
    def __init__(self, value: _Optional[int] = ..., **kwargs) -> None: ...

class ExpressionFloat(_message.Message):
    __slots__ = ("value",)
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        NONE: _ClassVar[ExpressionFloat.Type]
        EQUAL: _ClassVar[ExpressionFloat.Type]
        NOT_EQUAL: _ClassVar[ExpressionFloat.Type]
        GREATER_THAN: _ClassVar[ExpressionFloat.Type]
        GREATER_THAN_EQUAL: _ClassVar[ExpressionFloat.Type]
        LESS_THAN: _ClassVar[ExpressionFloat.Type]
        LESS_THAN_EQUAL: _ClassVar[ExpressionFloat.Type]
    NONE: ExpressionFloat.Type
    EQUAL: ExpressionFloat.Type
    NOT_EQUAL: ExpressionFloat.Type
    GREATER_THAN: ExpressionFloat.Type
    GREATER_THAN_EQUAL: ExpressionFloat.Type
    LESS_THAN: ExpressionFloat.Type
    LESS_THAN_EQUAL: ExpressionFloat.Type
    IS_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    value: float
    def __init__(self, value: _Optional[float] = ..., **kwargs) -> None: ...

class ExpressionString(_message.Message):
    __slots__ = ("value",)
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        NONE: _ClassVar[ExpressionString.Type]
        EQUAL: _ClassVar[ExpressionString.Type]
        NOT_EQUAL: _ClassVar[ExpressionString.Type]
        CONTAINING: _ClassVar[ExpressionString.Type]
        STARTING: _ClassVar[ExpressionString.Type]
    NONE: ExpressionString.Type
    EQUAL: ExpressionString.Type
    NOT_EQUAL: ExpressionString.Type
    CONTAINING: ExpressionString.Type
    STARTING: ExpressionString.Type
    IS_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    value: str
    def __init__(self, value: _Optional[str] = ..., **kwargs) -> None: ...

class ExpressionEnum(_message.Message):
    __slots__ = ("value",)
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        NONE: _ClassVar[ExpressionEnum.Type]
        EQUAL: _ClassVar[ExpressionEnum.Type]
        NOT_EQUAL: _ClassVar[ExpressionEnum.Type]
    NONE: ExpressionEnum.Type
    EQUAL: ExpressionEnum.Type
    NOT_EQUAL: ExpressionEnum.Type
    IS_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    value: str
    def __init__(self, value: _Optional[str] = ..., **kwargs) -> None: ...

class ExpressionBool(_message.Message):
    __slots__ = ("value",)
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        NONE: _ClassVar[ExpressionBool.Type]
        EQUAL: _ClassVar[ExpressionBool.Type]
    NONE: ExpressionBool.Type
    EQUAL: ExpressionBool.Type
    IS_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    value: bool
    def __init__(self, value: bool = ..., **kwargs) -> None: ...

class ExpressionTimestamp(_message.Message):
    __slots__ = ("value",)
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        NONE: _ClassVar[ExpressionTimestamp.Type]
        EQUAL: _ClassVar[ExpressionTimestamp.Type]
        NOT_EQUAL: _ClassVar[ExpressionTimestamp.Type]
        GREATER_THAN: _ClassVar[ExpressionTimestamp.Type]
        GREATER_THAN_EQUAL: _ClassVar[ExpressionTimestamp.Type]
        LESS_THAN: _ClassVar[ExpressionTimestamp.Type]
        LESS_THAN_EQUAL: _ClassVar[ExpressionTimestamp.Type]
    NONE: ExpressionTimestamp.Type
    EQUAL: ExpressionTimestamp.Type
    NOT_EQUAL: ExpressionTimestamp.Type
    GREATER_THAN: ExpressionTimestamp.Type
    GREATER_THAN_EQUAL: ExpressionTimestamp.Type
    LESS_THAN: ExpressionTimestamp.Type
    LESS_THAN_EQUAL: ExpressionTimestamp.Type
    IS_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    value: _timestamp_pb2.Timestamp
    def __init__(self, value: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., **kwargs) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/community/member.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/community/member.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.community import attribute_pb2 as eolymp_dot_community_dot_attribute__pb2
from eolymp.community import member_ghost_pb2 as eolymp_dot_community_dot_member__ghost__pb2
from eolymp.community import member_team_pb2 as eolymp_dot_community_dot_member__team__pb2
from eolymp.community import member_user_pb2 as eolymp_dot_community_dot_member__user__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/community/member.proto\x12\x10\x65olymp.community\x1a eolymp/community/attribute.proto\x1a#eolymp/community/member_ghost.proto\x1a\"eolymp/community/member_team.proto\x1a\"eolymp/community/member_user.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xac\x06\n\x06Member\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x0c\n\x04rank\x18\x46 \x01(\x05\x12\x12\n\nrank_lower\x18H \x01(\x05\x12\x0e\n\x06rating\x18G \x01(\x05\x12\r\n\x05level\x18O \x01(\r\x12\x10\n\x08inactive\x18\x0b \x01(\x08\x12\x12\n\nincomplete\x18\x14 \x01(\x08\x12\x12\n\nunofficial\x18\x1e \x01(\x08\x12\x0e\n\x06secret\x18( \x01(\x08\x12\x0f\n\x07tier_id\x18\x32 \x01(\t\x12\x18\n\x10\x66\x61llback_tier_id\x18\x33 \x01(\t\x12.\n\ncreated_at\x18< \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tseated_at\x18= \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tactive_at\x18> \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12&\n\x04user\x18\x64 \x01(\x0b\x32\x16.eolymp.community.UserH\x00\x12&\n\x04team\x18\x65 \x01(\x0b\x32\x16.eolymp.community.TeamH\x00\x12(\n\x05ghost\x18\x66 \x01(\x0b\x32\x17.eolymp.community.GhostH\x00\x12.\n\x05stats\x18\xac\x02 \x01(\x0b\x32\x1e.eolymp.community.Member.Stats\x12\x0f\n\x06groups\x18\xc8\x01 \x03(\t\x12\x36\n\nattributes\x18\x84\x07 \x03(\x0b\x32!.eolymp.community.Attribute.Value\x1ai\n\x05Stats\x12\x0e\n\x06streak\x18\n \x01(\x05\x12\x17\n\x0fproblems_solved\x18\x14 \x01(\x05\x12\x1c\n\x14submissions_accepted\x18\x1e \x01(\x05\x12\x19\n\x11submissions_total\x18) \x01(\x05\"F\n\x05\x45xtra\x12\x0c\n\x08NO_EXTRA\x10\x00\x12\x08\n\x04TIER\x10\x01\x12\t\n\x05STATS\x10\x02\x12\n\n\x06GROUPS\x10\x03\x12\x0e\n\nATTRIBUTES\x10\x04\x42\t\n\x07\x61\x63\x63ountB5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.member_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _globals['_MEMBER']._serialized_start=228
  _globals['_MEMBER']._serialized_end=1040
  _globals['_MEMBER_STATS']._serialized_start=852
  _globals['_MEMBER_STATS']._serialized_end=957
  _globals['_MEMBER_EXTRA']._serialized_start=959
  _globals['_MEMBER_EXTRA']._serialized_end=1029
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/printer/printer_job.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/printer/printer_job.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n eolymp/printer/printer_job.proto\x12\x0e\x65olymp.printer\x1a\x1fgoogle/protobuf/timestamp.proto\"\xc7\x02\n\x03Job\x12\n\n\x02id\x18\x01 \x01(\t\x12*\n\x06status\x18\x02 \x01(\x0e\x32\x1a.eolymp.printer.Job.Status\x12\x11\n\x07user_id\x18\n \x01(\tH\x00\x12\x13\n\tmember_id\x18\x0b \x01(\tH\x00\x12\x14\n\x0c\x64ocument_url\x18\x14 \x01(\t\x12.\n\ncreated_at\x18\x1e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x1f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"_\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0c\n\x08PRINTING\x10\x02\x12\x0c\n\x08\x43OMPLETE\x10\x03\x12\t\n\x05\x45RROR\x10\x04\x12\r\n\tCANCELLED\x10\x05\x42\t\n\x07\x63reatorB1Z/github.com/eolymp/go-sdk/eolymp/printer;printerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.printer.printer_job_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/printer;printer'
  _globals['_JOB']._serialized_start=86
  _globals['_JOB']._serialized_end=413
  _globals['_JOB_STATUS']._serialized_start=307
  _globals['_JOB_STATUS']._serialized_end=402
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.atlas import solution_pb2 as _solution_pb2
from eolymp.wellknown import direction_pb2 as _direction_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ListSolutionsInput(_message.Message):
    __slots__ = ("version", "offset", "size", "search", "filters", "sort", "order")
    class Sortable(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        NAME: _ClassVar[ListSolutionsInput.Sortable]
        TYPE: _ClassVar[ListSolutionsInput.Sortable]
    NAME: ListSolutionsInput.Sortable
    TYPE: ListSolutionsInput.Sortable
    class Filter(_message.Message):
        __slots__ = ("id", "type", "name", "runtime")
        ID_FIELD_NUMBER: _ClassVar[int]
        TYPE_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        RUNTIME_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        type: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        name: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        runtime: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., type: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ..., name: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ..., runtime: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ...) -> None: ...
    VERSION_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    SEARCH_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    SORT_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    version: int
    offset: int
    size: int
    search: str
    filters: ListSolutionsInput.Filter
    sort: ListSolutionsInput.Sortable
    order: _direction_pb2.Direction
    def __init__(self, version: _Optional[int] = ..., offset: _Optional[int] = ..., size: _Optional[int] = ..., search: _Optional[str] = ..., filters: _Optional[_Union[ListSolutionsInput.Filter, _Mapping]] = ..., sort: _Optional[_Union[ListSolutionsInput.Sortable, str]] = ..., order: _Optional[_Union[_direction_pb2.Direction, str]] = ...) -> None: ...

class ListSolutionsOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_solution_pb2.Solution]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_solution_pb2.Solution, _Mapping]]] = ...) -> None: ...

class CheckSolutionsInput(_message.Message):
    __slots__ = ("filters",)
    class Filter(_message.Message):
        __slots__ = ("id", "type", "name", "runtime")
        ID_FIELD_NUMBER: _ClassVar[int]
        TYPE_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        RUNTIME_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        type: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        name: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        runtime: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., type: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ..., name: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ..., runtime: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ...) -> None: ...
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    filters: CheckSolutionsInput.Filter
    def __init__(self, filters: _Optional[_Union[CheckSolutionsInput.Filter, _Mapping]] = ...) -> None: ...

class CheckSolutionsOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeSolutionInput(_message.Message):
    __slots__ = ("solution_id", "version")
    SOLUTION_ID_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    solution_id: str
    version: int
    def __init__(self, solution_id: _Optional[str] = ..., version: _Optional[int] = ...) -> None: ...

class DescribeSolutionOutput(_message.Message):
    __slots__ = ("solution",)
    SOLUTION_FIELD_NUMBER: _ClassVar[int]
    solution: _solution_pb2.Solution
    def __init__(self, solution: _Optional[_Union[_solution_pb2.Solution, _Mapping]] = ...) -> None: ...

class CreateSolutionInput(_message.Message):
    __slots__ = ("solution",)
    SOLUTION_FIELD_NUMBER: _ClassVar[int]
    solution: _solution_pb2.Solution
    def __init__(self, solution: _Optional[_Union[_solution_pb2.Solution, _Mapping]] = ...) -> None: ...

class CreateSolutionOutput(_message.Message):
    __slots__ = ("solution_id",)
    SOLUTION_ID_FIELD_NUMBER: _ClassVar[int]
    solution_id: str
    def __init__(self, solution_id: _Optional[str] = ...) -> None: ...

class UpdateSolutionInput(_message.Message):
    __slots__ = ("patch", "solution_id", "solution")
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        ALL: _ClassVar[UpdateSolutionInput.Patch]
        NAME: _ClassVar[UpdateSolutionInput.Patch]
        TYPE: _ClassVar[UpdateSolutionInput.Patch]
        RUNTIME: _ClassVar[UpdateSolutionInput.Patch]
        SOURCE: _ClassVar[UpdateSolutionInput.Patch]
        SECRET: _ClassVar[UpdateSolutionInput.Patch]
    ALL: UpdateSolutionInput.Patch
    NAME: UpdateSolutionInput.Patch
    TYPE: UpdateSolutionInput.Patch
    RUNTIME: UpdateSolutionInput.Patch
    SOURCE: UpdateSolutionInput.Patch
    SECRET: UpdateSolutionInput.Patch
    PATCH_FIELD_NUMBER: _ClassVar[int]
    SOLUTION_ID_FIELD_NUMBER: _ClassVar[int]
    SOLUTION_FIELD_NUMBER: _ClassVar[int]
    patch: _containers.RepeatedScalarFieldContainer[UpdateSolutionInput.Patch]
    solution_id: str
    solution: _solution_pb2.Solution
    def __init__(self, patch: _Optional[_Iterable[_Union[UpdateSolutionInput.Patch, str]]] = ..., solution_id: _Optional[str] = ..., solution: _Optional[_Union[_solution_pb2.Solution, _Mapping]] = ...) -> None: ...

class UpdateSolutionOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeleteSolutionInput(_message.Message):
    __slots__ = ("solution_id",)
    SOLUTION_ID_FIELD_NUMBER: _ClassVar[int]
    solution_id: str
    def __init__(self, solution_id: _Optional[str] = ...) -> None: ...

class DeleteSolutionOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/l10n/project_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/l10n/project_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.l10n import project_pb2 as eolymp_dot_l10n_dot_project__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!eolymp/l10n/project_service.proto\x12\x0b\x65olymp.l10n\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x19\x65olymp/l10n/project.proto\x1a!eolymp/wellknown/expression.proto\"\x9f\x01\n\x11ListProjectsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x36\n\x07\x66ilters\x18( \x01(\x0b\x32%.eolymp.l10n.ListProjectsInput.Filter\x1a\x34\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"H\n\x12ListProjectsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12#\n\x05items\x18\x02 \x03(\x0b\x32\x14.eolymp.l10n.Project\"*\n\x14\x44\x65scribeProjectInput\x12\x12\n\nproject_id\x18\x01 \x01(\t\">\n\x15\x44\x65scribeProjectOutput\x12%\n\x07project\x18\x01 \x01(\x0b\x32\x14.eolymp.l10n.Project2\xc0\x02\n\x0eProjectService\x12\x8a\x01\n\x0cListProjects\x12\x1e.eolymp.l10n.ListProjectsInput\x1a\x1f.eolymp.l10n.ListProjectsOutput\"9\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x15\x8a\xe3\n\x11l10n:project:read\x82\xd3\xe4\x93\x02\x0b\x12\t/projects\x12\xa0\x01\n\x0f\x44\x65scribeProject\x12!.eolymp.l10n.DescribeProjectInput\x1a\".eolymp.l10n.DescribeProjectOutput\"F\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x15\x8a\xe3\n\x11l10n:project:read\x82\xd3\xe4\x93\x02\x18\x12\x16/projects/{project_id}B+Z)github.com/eolymp/go-sdk/eolymp/l10n;l10nb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.l10n.project_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/eolymp/go-sdk/eolymp/l10n;l10n'
  _globals['_PROJECTSERVICE'].methods_by_name['ListProjects']._loaded_options = None
  _globals['_PROJECTSERVICE'].methods_by_name['ListProjects']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\025\212\343\n\021l10n:project:read\202\323\344\223\002\013\022\t/projects'
  _globals['_PROJECTSERVICE'].methods_by_name['DescribeProject']._loaded_options = None
  _globals['_PROJECTSERVICE'].methods_by_name['DescribeProject']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\025\212\343\n\021l10n:project:read\202\323\344\223\002\030\022\026/projects/{project_id}'
  _globals['_LISTPROJECTSINPUT']._serialized_start=212
  _globals['_LISTPROJECTSINPUT']._serialized_end=371
  _globals['_LISTPROJECTSINPUT_FILTER']._serialized_start=319
  _globals['_LISTPROJECTSINPUT_FILTER']._serialized_end=371
  _globals['_LISTPROJECTSOUTPUT']._serialized_start=373
  _globals['_LISTPROJECTSOUTPUT']._serialized_end=445
  _globals['_DESCRIBEPROJECTINPUT']._serialized_start=447
  _globals['_DESCRIBEPROJECTINPUT']._serialized_end=489
  _globals['_DESCRIBEPROJECTOUTPUT']._serialized_start=491
  _globals['_DESCRIBEPROJECTOUTPUT']._serialized_end=553
  _globals['_PROJECTSERVICE']._serialized_start=556
  _globals['_PROJECTSERVICE']._serialized_end=876
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/reward/achievement_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/reward/achievement_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.reward import achievement_pb2 as eolymp_dot_reward_dot_achievement__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'eolymp/reward/achievement_service.proto\x12\reolymp.reward\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1f\x65olymp/reward/achievement.proto\x1a!eolymp/wellknown/expression.proto\"I\n\x16\x43reateAchievementInput\x12/\n\x0b\x61\x63hievement\x18\x01 \x01(\x0b\x32\x1a.eolymp.reward.Achievement\"1\n\x17\x43reateAchievementOutput\x12\x16\n\x0e\x61\x63hievement_id\x18\x01 \x01(\t\"a\n\x16UpdateAchievementInput\x12\x16\n\x0e\x61\x63hievement_id\x18\x01 \x01(\t\x12/\n\x0b\x61\x63hievement\x18\x02 \x01(\x0b\x32\x1a.eolymp.reward.Achievement\"\x19\n\x17UpdateAchievementOutput\"0\n\x16\x44\x65leteAchievementInput\x12\x16\n\x0e\x61\x63hievement_id\x18\x01 \x01(\t\"\x19\n\x17\x44\x65leteAchievementOutput\"d\n\x18\x44\x65scribeAchievementInput\x12\x16\n\x0e\x61\x63hievement_id\x18\x01 \x01(\t\x12\x30\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32 .eolymp.reward.Achievement.Extra\"L\n\x19\x44\x65scribeAchievementOutput\x12/\n\x0b\x61\x63hievement\x18\x01 \x01(\x0b\x32\x1a.eolymp.reward.Achievement\"\xf9\x01\n\x15ListAchievementsInput\x12\r\n\x05\x61\x66ter\x18\x0c \x01(\t\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x0e\n\x06offset\x18\n \x01(\x05\x12<\n\x07\x66ilters\x18( \x01(\x0b\x32+.eolymp.reward.ListAchievementsInput.Filter\x12\x30\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32 .eolymp.reward.Achievement.Extra\x1a\x43\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"l\n\x16ListAchievementsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\x18\n\x10next_page_cursor\x18\x03 \x01(\t\x12)\n\x05items\x18\x02 \x03(\x0b\x32\x1a.eolymp.reward.Achievement\"\x87\x01\n#DescribeAchievementTranslationInput\x12\x16\n\x0e\x61\x63hievement_id\x18\x01 \x01(\t\x12\x16\n\x0etranslation_id\x18\x02 \x01(\t\x12\x30\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32 .eolymp.reward.Achievement.Extra\"c\n$DescribeAchievementTranslationOutput\x12;\n\x0btranslation\x18\x01 \x01(\x0b\x32&.eolymp.reward.Achievement.Translation\"\xca\x02\n ListAchievementTranslationsInput\x12\x16\n\x0e\x61\x63hievement_id\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12G\n\x07\x66ilters\x18( \x01(\x0b\x32\x36.eolymp.reward.ListAchievementTranslationsInput.Filter\x12\x30\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32 .eolymp.reward.Achievement.Extra\x1au\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x06locale\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"i\n!ListAchievementTranslationsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\x35\n\x05items\x18\x02 \x03(\x0b\x32&.eolymp.reward.Achievement.Translation\"x\n!CreateAchievementTranslationInput\x12\x16\n\x0e\x61\x63hievement_id\x18\x01 \x01(\t\x12;\n\x0btranslation\x18\x02 \x01(\x0b\x32&.eolymp.reward.Achievement.Translation\"<\n\"CreateAchievementTranslationOutput\x12\x16\n\x0etranslation_id\x18\x01 \x01(\t\"\x8c\x02\n!UpdateAchievementTranslationInput\x12\x45\n\x05patch\x18\x01 \x03(\x0e\x32\x36.eolymp.reward.UpdateAchievementTranslationInput.Patch\x12\x16\n\x0e\x61\x63hievement_id\x18\x02 \x01(\t\x12\x16\n\x0etranslation_id\x18\x03 \x01(\t\x12;\n\x0btranslation\x18\x04 \x01(\x0b\x32&.eolymp.reward.Achievement.Translation\"3\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x08\n\x04NAME\x10\x01\x12\x0b\n\x07SUMMARY\x10\x02\x12\n\n\x06LOCALE\x10\x03\"$\n\"UpdateAchievementTranslationOutput\"S\n!DeleteAchievementTranslationInput\x12\x16\n\x0e\x61\x63hievement_id\x18\x01 \x01(\t\x12\x16\n\x0etranslation_id\x18\x02 \x01(\t\"$\n\"DeleteAchievementTranslationOutput2\xe1\x10\n\x12\x41\x63hievementService\x12\xa6\x01\n\x11\x43reateAchievement\x12%.eolymp.reward.CreateAchievementInput\x1a&.eolymp.reward.CreateAchievementOutput\"B\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\x82\xd3\xe4\x93\x02\x0f\"\r/achievements\x12\xb7\x01\n\x11UpdateAchievement\x12%.eolymp.reward.UpdateAchievementInput\x1a&.eolymp.reward.UpdateAchievementOutput\"S\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\x82\xd3\xe4\x93\x02 \"\x1e/achievements/{achievement_id}\x12\xb7\x01\n\x11\x44\x65leteAchievement\x12%.eolymp.reward.DeleteAchievementInput\x1a&.eolymp.reward.DeleteAchievementOutput\"S\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\x82\xd3\xe4\x93\x02 *\x1e/achievements/{achievement_id}\x12\xbc\x01\n\x13\x44\x65scribeAchievement\x12\'.eolymp.reward.DescribeAchievementInput\x1a(.eolymp.reward.DescribeAchievementOutput\"R\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:read\x82\xd3\xe4\x93\x02 \x12\x1e/achievements/{achievement_id}\x12\xa2\x01\n\x10ListAchievements\x12$.eolymp.reward.ListAchievementsInput\x1a%.eolymp.reward.ListAchievementsOutput\"A\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:read\x82\xd3\xe4\x93\x02\x0f\x12\r/achievements\x12\xff\x01\n\x1e\x44\x65scribeAchievementTranslation\x12\x32.eolymp.reward.DescribeAchievementTranslationInput\x1a\x33.eolymp.reward.DescribeAchievementTranslationOutput\"t\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xe3\n\x1c\x8a\xe3\n\x18typewriter:fragment:read\x82\xd3\xe4\x93\x02>\x12</achievements/{achievement_id}/translations/{translation_id}\x12\xe4\x01\n\x1bListAchievementTranslations\x12/.eolymp.reward.ListAchievementTranslationsInput\x1a\x30.eolymp.reward.ListAchievementTranslationsOutput\"b\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x1c\x8a\xe3\n\x18typewriter:fragment:read\x82\xd3\xe4\x93\x02-\x12+/achievements/{achievement_id}/translations\x12\xe8\x01\n\x1c\x43reateAchievementTranslation\x12\x30.eolymp.reward.CreateAchievementTranslationInput\x1a\x31.eolymp.reward.CreateAchievementTranslationOutput\"c\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1d\x8a\xe3\n\x19typewriter:fragment:write\x82\xd3\xe4\x93\x02-\"+/achievements/{achievement_id}/translations\x12\xf9\x01\n\x1cUpdateAchievementTranslation\x12\x30.eolymp.reward.UpdateAchievementTranslationInput\x1a\x31.eolymp.reward.UpdateAchievementTranslationOutput\"t\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1d\x8a\xe3\n\x19typewriter:fragment:write\x82\xd3\xe4\x93\x02>\x1a</achievements/{achievement_id}/translations/{translation_id}\x12\xf9\x01\n\x1c\x44\x65leteAchievementTranslation\x12\x30.eolymp.reward.DeleteAchievementTranslationInput\x1a\x31.eolymp.reward.DeleteAchievementTranslationOutput\"t\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1d\x8a\xe3\n\x19typewriter:fragment:write\x82\xd3\xe4\x93\x02>*</achievements/{achievement_id}/translations/{translation_id}B/Z-github.com/eolymp/go-sdk/eolymp/reward;rewardb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.reward.achievement_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/reward;reward'
  _globals['_ACHIEVEMENTSERVICE'].methods_by_name['CreateAchievement']._loaded_options = None
  _globals['_ACHIEVEMENTSERVICE'].methods_by_name['CreateAchievement']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\032\212\343\n\026community:member:write\202\323\344\223\002\017\"\r/achievements'
  _globals['_ACHIEVEMENTSERVICE'].methods_by_name['UpdateAchievement']._loaded_options = None
  _globals['_ACHIEVEMENTSERVICE'].methods_by_name['UpdateAchievement']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\032\212\343\n\026community:member:write\202\323\344\223\002 \"\036/achievements/{achievement_id}'
  _globals['_ACHIEVEMENTSERVICE'].methods_by_name['DeleteAchievement']._loaded_options = None
  _globals['_ACHIEVEMENTSERVICE'].methods_by_name['DeleteAchievement']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\032\212\343\n\026community:member:write\202\323\344\223\002 *\036/achievements/{achievement_id}'
  _globals['_ACHIEVEMENTSERVICE'].methods_by_name['DescribeAchievement']._loaded_options = None
  _globals['_ACHIEVEMENTSERVICE'].methods_by_name['DescribeAchievement']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\031\212\343\n\025community:member:read\202\323\344\223\002 \022\036/achievements/{achievement_id}'
  _globals['_ACHIEVEMENTSERVICE'].methods_by_name['ListAchievements']._loaded_options = None
  _globals['_ACHIEVEMENTSERVICE'].methods_by_name['ListAchievements']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\031\212\343\n\025community:member:read\202\323\344\223\002\017\022\r/achievements'
  _globals['_ACHIEVEMENTSERVICE'].methods_by_name['DescribeAchievementTranslation']._loaded_options = None
  _globals['_ACHIEVEMENTSERVICE'].methods_by_name['DescribeAchievementTranslation']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\343\n\034\212\343\n\030typewriter:fragment:read\202\323\344\223\002>\022</achievements/{achievement_id}/translations/{translation_id}'
  _globals['_ACHIEVEMENTSERVICE'].methods_by_name['ListAchievementTranslations']._loaded_options = None
  _globals['_ACHIEVEMENTSERVICE'].methods_by_name['ListAchievementTranslations']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\034\212\343\n\030typewriter:fragment:read\202\323\344\223\002-\022+/achievements/{achievement_id}/translations'
  _globals['_ACHIEVEMENTSERVICE'].methods_by_name['CreateAchievementTranslation']._loaded_options = None
  _globals['_ACHIEVEMENTSERVICE'].methods_by_name['CreateAchievementTranslation']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\035\212\343\n\031typewriter:fragment:write\202\323\344\223\002-\"+/achievements/{achievement_id}/translations'
  _globals['_ACHIEVEMENTSERVICE'].methods_by_name['UpdateAchievementTranslation']._loaded_options = None
  _globals['_ACHIEVEMENTSERVICE'].methods_by_name['UpdateAchievementTranslation']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\035\212\343\n\031typewriter:fragment:write\202\323\344\223\002>\032</achievements/{achievement_id}/translations/{translation_id}'
  _globals['_ACHIEVEMENTSERVICE'].methods_by_name['DeleteAchievementTranslation']._loaded_options = None
  _globals['_ACHIEVEMENTSERVICE'].methods_by_name['DeleteAchievementTranslation']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\035\212\343\n\031typewriter:fragment:write\202\323\344\223\002>*</achievements/{achievement_id}/translations/{translation_id}'
  _globals['_CREATEACHIEVEMENTINPUT']._serialized_start=225
  _globals['_CREATEACHIEVEMENTINPUT']._serialized_end=298
  _globals['_CREATEACHIEVEMENTOUTPUT']._serialized_start=300
  _globals['_CREATEACHIEVEMENTOUTPUT']._serialized_end=349
  _globals['_UPDATEACHIEVEMENTINPUT']._serialized_start=351
  _globals['_UPDATEACHIEVEMENTINPUT']._serialized_end=448
  _globals['_UPDATEACHIEVEMENTOUTPUT']._serialized_start=450
  _globals['_UPDATEACHIEVEMENTOUTPUT']._serialized_end=475
  _globals['_DELETEACHIEVEMENTINPUT']._serialized_start=477
  _globals['_DELETEACHIEVEMENTINPUT']._serialized_end=525
  _globals['_DELETEACHIEVEMENTOUTPUT']._serialized_start=527
  _globals['_DELETEACHIEVEMENTOUTPUT']._serialized_end=552
  _globals['_DESCRIBEACHIEVEMENTINPUT']._serialized_start=554
  _globals['_DESCRIBEACHIEVEMENTINPUT']._serialized_end=654
  _globals['_DESCRIBEACHIEVEMENTOUTPUT']._serialized_start=656
  _globals['_DESCRIBEACHIEVEMENTOUTPUT']._serialized_end=732
  _globals['_LISTACHIEVEMENTSINPUT']._serialized_start=735
  _globals['_LISTACHIEVEMENTSINPUT']._serialized_end=984
  _globals['_LISTACHIEVEMENTSINPUT_FILTER']._serialized_start=917
  _globals['_LISTACHIEVEMENTSINPUT_FILTER']._serialized_end=984
  _globals['_LISTACHIEVEMENTSOUTPUT']._serialized_start=986
  _globals['_LISTACHIEVEMENTSOUTPUT']._serialized_end=1094
  _globals['_DESCRIBEACHIEVEMENTTRANSLATIONINPUT']._serialized_start=1097
  _globals['_DESCRIBEACHIEVEMENTTRANSLATIONINPUT']._serialized_end=1232
  _globals['_DESCRIBEACHIEVEMENTTRANSLATIONOUTPUT']._serialized_start=1234
  _globals['_DESCRIBEACHIEVEMENTTRANSLATIONOUTPUT']._serialized_end=1333
  _globals['_LISTACHIEVEMENTTRANSLATIONSINPUT']._serialized_start=1336
  _globals['_LISTACHIEVEMENTTRANSLATIONSINPUT']._serialized_end=1666
  _globals['_LISTACHIEVEMENTTRANSLATIONSINPUT_FILTER']._serialized_start=1549
  _globals['_LISTACHIEVEMENTTRANSLATIONSINPUT_FILTER']._serialized_end=1666
  _globals['_LISTACHIEVEMENTTRANSLATIONSOUTPUT']._serialized_start=1668
  _globals['_LISTACHIEVEMENTTRANSLATIONSOUTPUT']._serialized_end=1773
  _globals['_CREATEACHIEVEMENTTRANSLATIONINPUT']._serialized_start=1775
  _globals['_CREATEACHIEVEMENTTRANSLATIONINPUT']._serialized_end=1895
  _globals['_CREATEACHIEVEMENTTRANSLATIONOUTPUT']._serialized_start=1897
  _globals['_CREATEACHIEVEMENTTRANSLATIONOUTPUT']._serialized_end=1957
  _globals['_UPDATEACHIEVEMENTTRANSLATIONINPUT']._serialized_start=1960
  _globals['_UPDATEACHIEVEMENTTRANSLATIONINPUT']._serialized_end=2228
  _globals['_UPDATEACHIEVEMENTTRANSLATIONINPUT_PATCH']._serialized_start=2177
  _globals['_UPDATEACHIEVEMENTTRANSLATIONINPUT_PATCH']._serialized_end=2228
  _globals['_UPDATEACHIEVEMENTTRANSLATIONOUTPUT']._serialized_start=2230
  _globals['_UPDATEACHIEVEMENTTRANSLATIONOUTPUT']._serialized_end=2266
  _globals['_DELETEACHIEVEMENTTRANSLATIONINPUT']._serialized_start=2268
  _globals['_DELETEACHIEVEMENTTRANSLATIONINPUT']._serialized_end=2351
  _globals['_DELETEACHIEVEMENTTRANSLATIONOUTPUT']._serialized_start=2353
  _globals['_DELETEACHIEVEMENTTRANSLATIONOUTPUT']._serialized_end=2389
  _globals['_ACHIEVEMENTSERVICE']._serialized_start=2392
  _globals['_ACHIEVEMENTSERVICE']._serialized_end=4537
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/certificate/certificate_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/certificate/certificate_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.certificate import certificate_pb2 as eolymp_dot_certificate_dot_certificate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,eolymp/certificate/certificate_service.proto\x12\x12\x65olymp.certificate\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a$eolymp/certificate/certificate.proto\"N\n\x16\x43reateCertificateInput\x12\x34\n\x0b\x63\x65rtificate\x18\x01 \x01(\x0b\x32\x1f.eolymp.certificate.Certificate\"G\n\x17\x43reateCertificateOutput\x12\x16\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\t\x12\x14\n\x0c\x64ownload_url\x18\x02 \x01(\t\".\n\x14VoidCertificateInput\x12\x16\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\t\"\x17\n\x15VoidCertificateOutput\"2\n\x18\x44\x65scribeCertificateInput\x12\x16\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\t\"Q\n\x19\x44\x65scribeCertificateOutput\x12\x34\n\x0b\x63\x65rtificate\x18\x01 \x01(\x0b\x32\x1f.eolymp.certificate.Certificate\"H\n\x15ListCertificatesInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x11\n\tmember_id\x18\x14 \x01(\t\"W\n\x16ListCertificatesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12.\n\x05items\x18\x02 \x03(\x0b\x32\x1f.eolymp.certificate.Certificate2\xad\x06\n\x12\x43\x65rtificateService\x12\xb7\x01\n\x11\x43reateCertificate\x12*.eolymp.certificate.CreateCertificateInput\x1a+.eolymp.certificate.CreateCertificateOutput\"I\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xe3\n!\x8a\xe3\n\x1d\x63\x65rtificate:certificate:write\x82\xd3\xe4\x93\x02\x0f\"\r/certificates\x12\xc2\x01\n\x0fVoidCertificate\x12(.eolymp.certificate.VoidCertificateInput\x1a).eolymp.certificate.VoidCertificateOutput\"Z\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xe3\n!\x8a\xe3\n\x1d\x63\x65rtificate:certificate:write\x82\xd3\xe4\x93\x02 *\x1e/certificates/{certificate_id}\x12\xcd\x01\n\x13\x44\x65scribeCertificate\x12,.eolymp.certificate.DescribeCertificateInput\x1a-.eolymp.certificate.DescribeCertificateOutput\"Y\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n \x8a\xe3\n\x1c\x63\x65rtificate:certificate:read\x82\xd3\xe4\x93\x02 \x12\x1e/certificates/{certificate_id}\x12\xc7\x01\n\x10ListCertificates\x12).eolymp.certificate.ListCertificatesInput\x1a*.eolymp.certificate.ListCertificatesOutput\"\\\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n \x8a\xe3\n\x1c\x63\x65rtificate:certificate:read\x82\xd3\xe4\x93\x02#\x12!/members/{member_id}/certificatesB9Z7github.com/eolymp/go-sdk/eolymp/certificate;certificateb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.certificate.certificate_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/eolymp/go-sdk/eolymp/certificate;certificate'
  _globals['_CERTIFICATESERVICE'].methods_by_name['CreateCertificate']._loaded_options = None
  _globals['_CERTIFICATESERVICE'].methods_by_name['CreateCertificate']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\343\n!\212\343\n\035certificate:certificate:write\202\323\344\223\002\017\"\r/certificates'
  _globals['_CERTIFICATESERVICE'].methods_by_name['VoidCertificate']._loaded_options = None
  _globals['_CERTIFICATESERVICE'].methods_by_name['VoidCertificate']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\343\n!\212\343\n\035certificate:certificate:write\202\323\344\223\002 *\036/certificates/{certificate_id}'
  _globals['_CERTIFICATESERVICE'].methods_by_name['DescribeCertificate']._loaded_options = None
  _globals['_CERTIFICATESERVICE'].methods_by_name['DescribeCertificate']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n \212\343\n\034certificate:certificate:read\202\323\344\223\002 \022\036/certificates/{certificate_id}'
  _globals['_CERTIFICATESERVICE'].methods_by_name['ListCertificates']._loaded_options = None
  _globals['_CERTIFICATESERVICE'].methods_by_name['ListCertificates']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n \212\343\n\034certificate:certificate:read\202\323\344\223\002#\022!/members/{member_id}/certificates'
  _globals['_CREATECERTIFICATEINPUT']._serialized_start=205
  _globals['_CREATECERTIFICATEINPUT']._serialized_end=283
  _globals['_CREATECERTIFICATEOUTPUT']._serialized_start=285
  _globals['_CREATECERTIFICATEOUTPUT']._serialized_end=356
  _globals['_VOIDCERTIFICATEINPUT']._serialized_start=358
  _globals['_VOIDCERTIFICATEINPUT']._serialized_end=404
  _globals['_VOIDCERTIFICATEOUTPUT']._serialized_start=406
  _globals['_VOIDCERTIFICATEOUTPUT']._serialized_end=429
  _globals['_DESCRIBECERTIFICATEINPUT']._serialized_start=431
  _globals['_DESCRIBECERTIFICATEINPUT']._serialized_end=481
  _globals['_DESCRIBECERTIFICATEOUTPUT']._serialized_start=483
  _globals['_DESCRIBECERTIFICATEOUTPUT']._serialized_end=564
  _globals['_LISTCERTIFICATESINPUT']._serialized_start=566
  _globals['_LISTCERTIFICATESINPUT']._serialized_end=638
  _globals['_LISTCERTIFICATESOUTPUT']._serialized_start=640
  _globals['_LISTCERTIFICATESOUTPUT']._serialized_end=727
  _globals['_CERTIFICATESERVICE']._serialized_start=730
  _globals['_CERTIFICATESERVICE']._serialized_end=1543
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.discussion import post_pb2 as _post_pb2
from eolymp.ecm import content_pb2 as _content_pb2
from eolymp.wellknown import direction_pb2 as _direction_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PostChangedEvent(_message.Message):
    __slots__ = ("before", "after", "reason")
    BEFORE_FIELD_NUMBER: _ClassVar[int]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    before: _post_pb2.Post
    after: _post_pb2.Post
    reason: _content_pb2.Content
    def __init__(self, before: _Optional[_Union[_post_pb2.Post, _Mapping]] = ..., after: _Optional[_Union[_post_pb2.Post, _Mapping]] = ..., reason: _Optional[_Union[_content_pb2.Content, _Mapping]] = ...) -> None: ...

class PostPublishedEvent(_message.Message):
    __slots__ = ("published", "post", "reason")
    PUBLISHED_FIELD_NUMBER: _ClassVar[int]
    POST_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    published: bool
    post: _post_pb2.Post
    reason: _content_pb2.Content
    def __init__(self, published: bool = ..., post: _Optional[_Union[_post_pb2.Post, _Mapping]] = ..., reason: _Optional[_Union[_content_pb2.Content, _Mapping]] = ...) -> None: ...

class PostTranslationChangedEvent(_message.Message):
    __slots__ = ("post_id", "before", "after", "reason")
    POST_ID_FIELD_NUMBER: _ClassVar[int]
    BEFORE_FIELD_NUMBER: _ClassVar[int]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    post_id: str
    before: _post_pb2.Post.Translation
    after: _post_pb2.Post.Translation
    reason: _content_pb2.Content
    def __init__(self, post_id: _Optional[str] = ..., before: _Optional[_Union[_post_pb2.Post.Translation, _Mapping]] = ..., after: _Optional[_Union[_post_pb2.Post.Translation, _Mapping]] = ..., reason: _Optional[_Union[_content_pb2.Content, _Mapping]] = ...) -> None: ...

class DescribePostInput(_message.Message):
    __slots__ = ("post_id", "locale", "extra")
    POST_ID_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    post_id: str
    locale: str
    extra: _containers.RepeatedScalarFieldContainer[_post_pb2.Post.Extra]
    def __init__(self, post_id: _Optional[str] = ..., locale: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_post_pb2.Post.Extra, str]]] = ...) -> None: ...

class DescribePostOutput(_message.Message):
    __slots__ = ("post",)
    POST_FIELD_NUMBER: _ClassVar[int]
    post: _post_pb2.Post
    def __init__(self, post: _Optional[_Union[_post_pb2.Post, _Mapping]] = ...) -> None: ...

class ListPostsInput(_message.Message):
    __slots__ = ("after", "size", "offset", "sort", "order", "filters", "locale", "extra")
    class Sort(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_SORT: _ClassVar[ListPostsInput.Sort]
        PUBLISHED_AT: _ClassVar[ListPostsInput.Sort]
        CREATED_AT: _ClassVar[ListPostsInput.Sort]
        VOTE_COUNT: _ClassVar[ListPostsInput.Sort]
        REPLY_COUNT: _ClassVar[ListPostsInput.Sort]
        POPULARITY: _ClassVar[ListPostsInput.Sort]
    UNKNOWN_SORT: ListPostsInput.Sort
    PUBLISHED_AT: ListPostsInput.Sort
    CREATED_AT: ListPostsInput.Sort
    VOTE_COUNT: ListPostsInput.Sort
    REPLY_COUNT: ListPostsInput.Sort
    POPULARITY: ListPostsInput.Sort
    class Filter(_message.Message):
        __slots__ = ("query", "id", "source_id", "user_id", "member_id", "type_id", "created_at", "published_at", "draft", "public", "featured", "moderation", "locale", "label")
        QUERY_FIELD_NUMBER: _ClassVar[int]
        ID_FIELD_NUMBER: _ClassVar[int]
        SOURCE_ID_FIELD_NUMBER: _ClassVar[int]
        USER_ID_FIELD_NUMBER: _ClassVar[int]
        MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
        TYPE_ID_FIELD_NUMBER: _ClassVar[int]
        CREATED_AT_FIELD_NUMBER: _ClassVar[int]
        PUBLISHED_AT_FIELD_NUMBER: _ClassVar[int]
        DRAFT_FIELD_NUMBER: _ClassVar[int]
        PUBLIC_FIELD_NUMBER: _ClassVar[int]
        FEATURED_FIELD_NUMBER: _ClassVar[int]
        MODERATION_FIELD_NUMBER: _ClassVar[int]
        LOCALE_FIELD_NUMBER: _ClassVar[int]
        LABEL_FIELD_NUMBER: _ClassVar[int]
        query: str
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        source_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        user_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        member_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        type_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        created_at: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionTimestamp]
        published_at: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionTimestamp]
        draft: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionBool]
        public: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionBool]
        featured: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionBool]
        moderation: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        locale: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        label: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        def __init__(self, query: _Optional[str] = ..., id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., source_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., user_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., member_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., type_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., created_at: _Optional[_Iterable[_Union[_expression_pb2.ExpressionTimestamp, _Mapping]]] = ..., published_at: _Optional[_Iterable[_Union[_expression_pb2.ExpressionTimestamp, _Mapping]]] = ..., draft: _Optional[_Iterable[_Union[_expression_pb2.ExpressionBool, _Mapping]]] = ..., public: _Optional[_Iterable[_Union[_expression_pb2.ExpressionBool, _Mapping]]] = ..., featured: _Optional[_Iterable[_Union[_expression_pb2.ExpressionBool, _Mapping]]] = ..., moderation: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ..., locale: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ..., label: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ...) -> None: ...
    AFTER_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SORT_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    after: str
    size: int
    offset: int
    sort: ListPostsInput.Sort
    order: _direction_pb2.Direction
    filters: ListPostsInput.Filter
    locale: str
    extra: _containers.RepeatedScalarFieldContainer[_post_pb2.Post.Extra]
    def __init__(self, after: _Optional[str] = ..., size: _Optional[int] = ..., offset: _Optional[int] = ..., sort: _Optional[_Union[ListPostsInput.Sort, str]] = ..., order: _Optional[_Union[_direction_pb2.Direction, str]] = ..., filters: _Optional[_Union[ListPostsInput.Filter, _Mapping]] = ..., locale: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_post_pb2.Post.Extra, str]]] = ...) -> None: ...

class ListPostsOutput(_message.Message):
    __slots__ = ("total", "items", "next_page_cursor")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_CURSOR_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_post_pb2.Post]
    next_page_cursor: str
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_post_pb2.Post, _Mapping]]] = ..., next_page_cursor: _Optional[str] = ...) -> None: ...

class CreatePostInput(_message.Message):
    __slots__ = ("post",)
    POST_FIELD_NUMBER: _ClassVar[int]
    post: _post_pb2.Post
    def __init__(self, post: _Optional[_Union[_post_pb2.Post, _Mapping]] = ...) -> None: ...

class CreatePostOutput(_message.Message):
    __slots__ = ("post_id",)
    POST_ID_FIELD_NUMBER: _ClassVar[int]
    post_id: str
    def __init__(self, post_id: _Optional[str] = ...) -> None: ...

class UpdatePostInput(_message.Message):
    __slots__ = ("patch", "post_id", "post")
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        ALL: _ClassVar[UpdatePostInput.Patch]
        CONTENT: _ClassVar[UpdatePostInput.Patch]
        LABELS: _ClassVar[UpdatePostInput.Patch]
        TYPE_ID: _ClassVar[UpdatePostInput.Patch]
        LOCALE: _ClassVar[UpdatePostInput.Patch]
        DRAFT: _ClassVar[UpdatePostInput.Patch]
        FEATURED: _ClassVar[UpdatePostInput.Patch]
        PINNED: _ClassVar[UpdatePostInput.Patch]
        MODERATION: _ClassVar[UpdatePostInput.Patch]
    ALL: UpdatePostInput.Patch
    CONTENT: UpdatePostInput.Patch
    LABELS: UpdatePostInput.Patch
    TYPE_ID: UpdatePostInput.Patch
    LOCALE: UpdatePostInput.Patch
    DRAFT: UpdatePostInput.Patch
    FEATURED: UpdatePostInput.Patch
    PINNED: UpdatePostInput.Patch
    MODERATION: UpdatePostInput.Patch
    PATCH_FIELD_NUMBER: _ClassVar[int]
    POST_ID_FIELD_NUMBER: _ClassVar[int]
    POST_FIELD_NUMBER: _ClassVar[int]
    patch: _containers.RepeatedScalarFieldContainer[UpdatePostInput.Patch]
    post_id: str
    post: _post_pb2.Post
    def __init__(self, patch: _Optional[_Iterable[_Union[UpdatePostInput.Patch, str]]] = ..., post_id: _Optional[str] = ..., post: _Optional[_Union[_post_pb2.Post, _Mapping]] = ...) -> None: ...

class UpdatePostOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class PublishPostInput(_message.Message):
    __slots__ = ("post_id",)
    POST_ID_FIELD_NUMBER: _ClassVar[int]
    post_id: str
    def __init__(self, post_id: _Optional[str] = ...) -> None: ...

class PublishPostOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class UnpublishPostInput(_message.Message):
    __slots__ = ("post_id", "reason")
    POST_ID_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    post_id: str
    reason: _content_pb2.Content
    def __init__(self, post_id: _Optional[str] = ..., reason: _Optional[_Union[_content_pb2.Content, _Mapping]] = ...) -> None: ...

class UnpublishPostOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ModeratePostInput(_message.Message):
    __slots__ = ("post_id", "outcome", "reason")
    class Outcome(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_OUTCOME: _ClassVar[ModeratePostInput.Outcome]
        APPROVED: _ClassVar[ModeratePostInput.Outcome]
        REJECTED: _ClassVar[ModeratePostInput.Outcome]
        IN_REVIEW: _ClassVar[ModeratePostInput.Outcome]
    UNKNOWN_OUTCOME: ModeratePostInput.Outcome
    APPROVED: ModeratePostInput.Outcome
    REJECTED: ModeratePostInput.Outcome
    IN_REVIEW: ModeratePostInput.Outcome
    POST_ID_FIELD_NUMBER: _ClassVar[int]
    OUTCOME_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    post_id: str
    outcome: ModeratePostInput.Outcome
    reason: _content_pb2.Content
    def __init__(self, post_id: _Optional[str] = ..., outcome: _Optional[_Union[ModeratePostInput.Outcome, str]] = ..., reason: _Optional[_Union[_content_pb2.Content, _Mapping]] = ...) -> None: ...

class ModeratePostOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeletePostInput(_message.Message):
    __slots__ = ("post_id",)
    POST_ID_FIELD_NUMBER: _ClassVar[int]
    post_id: str
    def __init__(self, post_id: _Optional[str] = ...) -> None: ...

class DeletePostOutput(_message.Message):
    __slots__ = ("reason",)
    REASON_FIELD_NUMBER: _ClassVar[int]
    reason: _content_pb2.Content
    def __init__(self, reason: _Optional[_Union[_content_pb2.Content, _Mapping]] = ...) -> None: ...

class VotePostInput(_message.Message):
    __slots__ = ("post_id", "vote")
    POST_ID_FIELD_NUMBER: _ClassVar[int]
    VOTE_FIELD_NUMBER: _ClassVar[int]
    post_id: str
    vote: int
    def __init__(self, post_id: _Optional[str] = ..., vote: _Optional[int] = ...) -> None: ...

class VotePostOutput(_message.Message):
    __slots__ = ("vote_count",)
    VOTE_COUNT_FIELD_NUMBER: _ClassVar[int]
    vote_count: int
    def __init__(self, vote_count: _Optional[int] = ...) -> None: ...

class TranslatePostInput(_message.Message):
    __slots__ = ("post_id", "source", "target", "target_automatic", "override_manual")
    POST_ID_FIELD_NUMBER: _ClassVar[int]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    TARGET_FIELD_NUMBER: _ClassVar[int]
    TARGET_AUTOMATIC_FIELD_NUMBER: _ClassVar[int]
    OVERRIDE_MANUAL_FIELD_NUMBER: _ClassVar[int]
    post_id: str
    source: str
    target: _containers.RepeatedScalarFieldContainer[str]
    target_automatic: bool
    override_manual: bool
    def __init__(self, post_id: _Optional[str] = ..., source: _Optional[str] = ..., target: _Optional[_Iterable[str]] = ..., target_automatic: bool = ..., override_manual: bool = ...) -> None: ...

class TranslatePostOutput(_message.Message):
    __slots__ = ("job_id",)
    JOB_ID_FIELD_NUMBER: _ClassVar[int]
    job_id: str
    def __init__(self, job_id: _Optional[str] = ...) -> None: ...

class DescribePostTranslationInput(_message.Message):
    __slots__ = ("post_id", "translation_id", "extra")
    POST_ID_FIELD_NUMBER: _ClassVar[int]
    TRANSLATION_ID_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    post_id: str
    translation_id: str
    extra: _containers.RepeatedScalarFieldContainer[_post_pb2.Post.Extra]
    def __init__(self, post_id: _Optional[str] = ..., translation_id: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_post_pb2.Post.Extra, str]]] = ...) -> None: ...

class DescribePostTranslationOutput(_message.Message):
    __slots__ = ("translation",)
    TRANSLATION_FIELD_NUMBER: _ClassVar[int]
    translation: _post_pb2.Post.Translation
    def __init__(self, translation: _Optional[_Union[_post_pb2.Post.Translation, _Mapping]] = ...) -> None: ...

class ListPostTranslationsInput(_message.Message):
    __slots__ = ("post_id", "offset", "size", "filters", "extra")
    class Filter(_message.Message):
        __slots__ = ("query", "id", "locale")
        QUERY_FIELD_NUMBER: _ClassVar[int]
        ID_FIELD_NUMBER: _ClassVar[int]
        LOCALE_FIELD_NUMBER: _ClassVar[int]
        query: str
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        locale: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        def __init__(self, query: _Optional[str] = ..., id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., locale: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ...) -> None: ...
    POST_ID_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    post_id: str
    offset: int
    size: int
    filters: ListPostTranslationsInput.Filter
    extra: _containers.RepeatedScalarFieldContainer[_post_pb2.Post.Extra]
    def __init__(self, post_id: _Optional[str] = ..., offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListPostTranslationsInput.Filter, _Mapping]] = ..., extra: _Optional[_Iterable[_Union[_post_pb2.Post.Extra, str]]] = ...) -> None: ...

class ListPostTranslationsOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_post_pb2.Post.Translation]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_post_pb2.Post.Translation, _Mapping]]] = ...) -> None: ...

class CreatePostTranslationInput(_message.Message):
    __slots__ = ("post_id", "translation")
    POST_ID_FIELD_NUMBER: _ClassVar[int]
    TRANSLATION_FIELD_NUMBER: _ClassVar[int]
    post_id: str
    translation: _post_pb2.Post.Translation
    def __init__(self, post_id: _Optional[str] = ..., translation: _Optional[_Union[_post_pb2.Post.Translation, _Mapping]] = ...) -> None: ...

class CreatePostTranslationOutput(_message.Message):
    __slots__ = ("translation_id",)
    TRANSLATION_ID_FIELD_NUMBER: _ClassVar[int]
    translation_id: str
    def __init__(self, translation_id: _Optional[str] = ...) -> None: ...

class UpdatePostTranslationInput(_message.Message):
    __slots__ = ("patch", "post_id", "translation_id", "translation")
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        ALL: _ClassVar[UpdatePostTranslationInput.Patch]
        CONTENT: _ClassVar[UpdatePostTranslationInput.Patch]
        LABELS: _ClassVar[UpdatePostTranslationInput.Patch]
        LOCALE: _ClassVar[UpdatePostTranslationInput.Patch]
    ALL: UpdatePostTranslationInput.Patch
    CONTENT: UpdatePostTranslationInput.Patch
    LABELS: UpdatePostTranslationInput.Patch
    LOCALE: UpdatePostTranslationInput.Patch
    PATCH_FIELD_NUMBER: _ClassVar[int]
    POST_ID_FIELD_NUMBER: _ClassVar[int]
    TRANSLATION_ID_FIELD_NUMBER: _ClassVar[int]
    TRANSLATION_FIELD_NUMBER: _ClassVar[int]
    patch: _containers.RepeatedScalarFieldContainer[UpdatePostTranslationInput.Patch]
    post_id: str
    translation_id: str
    translation: _post_pb2.Post.Translation
    def __init__(self, patch: _Optional[_Iterable[_Union[UpdatePostTranslationInput.Patch, str]]] = ..., post_id: _Optional[str] = ..., translation_id: _Optional[str] = ..., translation: _Optional[_Union[_post_pb2.Post.Translation, _Mapping]] = ...) -> None: ...

class UpdatePostTranslationOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeletePostTranslationInput(_message.Message):
    __slots__ = ("post_id", "translation_id")
    POST_ID_FIELD_NUMBER: _ClassVar[int]
    TRANSLATION_ID_FIELD_NUMBER: _ClassVar[int]
    post_id: str
    translation_id: str
    def __init__(self, post_id: _Optional[str] = ..., translation_id: _Optional[str] = ...) -> None: ...

class DeletePostTranslationOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...
